@@ -5,7 +5,7 @@ from typing import Iterator, List, Tuple
 from cognite.client.data_classes import Asset
 from cognite.experimental import CogniteClient
 
-from cognite.airworkflow.util.data_set_id import data_set_id
+from cognite.airworkflow.util.cdf import data_set_id
 
 from .scheduling import (
     Schedule,
@@ -19,6 +19,7 @@ from .scheduling import (
 
 AIR_INFRA = "airInfra"
 MODEL_POSTFIX = ":latest"
+DATA_SET_NAME = "AIR"
 
 
 def retrieve_infra_model_assets(client) -> Iterator[Asset]:
@@ -28,7 +29,7 @@ def retrieve_infra_model_assets(client) -> Iterator[Asset]:
 
 
 def retrieve_schedule_asset_without_asset(client: CogniteClient) -> List:
-    air_assets: List[Asset] = client.assets.list(data_set_ids=[data_set_id], limit=-1)
+    air_assets: List[Asset] = client.assets.list(data_set_ids=[data_set_id(client, DATA_SET_NAME)], limit=-1)
     assets: Iterator[Asset] = retrieve_infra_model_assets(client)
     assets_to_create: List[Asset] = []
     for asset in assets:
