@@ -5,7 +5,7 @@ import numpy as np
 from cognite.experimental import CogniteClient
 from cognite.experimental.data_classes import FunctionSchedule
 
-from cognite.airworkflow.data_set_id import data_set_id
+from cognite.airworkflow.util.cdf import data_set_id
 
 AIR_MODELS = "airModels"
 AIR_INFRA = "airInfra"
